@@ -582,6 +582,9 @@ void ARingGFGivaro::power(ElementType &result,
       assert(tmp >= 0);  // tmp<0 should never occur
       if (tmp < 0) tmp += givaroField.cardinality() - 1;
       result = tmp;
+      mpz_clear(mpz_a);
+      mpz_clear(mpz_n);
+      mpz_clear(mpz_tmp);
     }
   else
     {
