@@ -235,6 +235,16 @@ Matrix /* or null */ *rawSubduction(int numparts,
                                     const Matrix *M,
                                     const RingMap *F,
                                     Computation *C);
+   
+Matrix /* or null */ *rawSubduction1(int numparts,
+                                     const Ring *rawT,
+                                     const Ring *rawS,
+                                     const Matrix *m,
+                                     const RingMap *inclusionAmbient,
+                                     const RingMap *fullSubstitution,
+                                     const RingMap *substitutionInclusion,
+                                     Computation *rawGBI,
+                                     Computation *rawGBReductionIdeal); 
 
 void rawDisplayMatrixStream(const Matrix *inputMatrix);
 
